itemSize property
Size of Pin indicator item. Value is used in some animations. If size is not symmetric or different, provide estimate value.
Implementation
// This will be -1 for .builder constructor
final double itemSize;
Size of Pin indicator item. Value is used in some animations. If size is not symmetric or different, provide estimate value.
// This will be -1 for .builder constructor
final double itemSize;