successCollapseAnimationChild property
Widget that will appear on the screen after all indicator items are collapsed in case of PinSuccessAnimation.collapse is chosen.
Implementation
final Widget? successCollapseAnimationChild;
Widget that will appear on the screen after all indicator items are collapsed in case of PinSuccessAnimation.collapse is chosen.
final Widget? successCollapseAnimationChild;