PinInputAnimation enum

Enum with all input animations that can be played via controller in Pin indicator.

Input animations are used when user enters pin code's symbol.

Inheritance
Available extensions

Values

inflate → const PinInputAnimation
fall → const PinInputAnimation
fade → const PinInputAnimation

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PinInputAnimation>
A constant List of the values in this enum, in order of their declaration.