PinLoadingAnimation enum

Enum with all loading animations that can be played via controller in Pin indicator.

Loading animations are played when you need to delay async operations or show visual representation of loading state.

Inheritance
Available extensions

Values

jump → const PinLoadingAnimation
waveInflate → const PinLoadingAnimation
waveDeflate → const PinLoadingAnimation
waveFade → const PinLoadingAnimation
collapse → const PinLoadingAnimation
travel → const PinLoadingAnimation

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PinLoadingAnimation>
A constant List of the values in this enum, in order of their declaration.