isVisible property

bool isVisible
final

If pinpad is visible. When it is hidden, size will remain the same. This parameter is useful for some Pin Indicator animations.

Implementation

final bool isVisible;