keyDisabledDecoration property
Decoration that will be applied for keys when they are disabled.
Implementation
final BoxDecoration? keyDisabledDecoration;
Decoration that will be applied for keys when they are disabled.
final BoxDecoration? keyDisabledDecoration;