keyPressedDecoration property
Decoration that will be applied for key when it is pressed.
Implementation
final BoxDecoration? keyPressedDecoration;
Decoration that will be applied for key when it is pressed.
final BoxDecoration? keyPressedDecoration;