leftExtraKey property
Data for widget that will be displayed on the left side of zero key button.
Implementation
final PinpadExtraKey? leftExtraKey;
Data for widget that will be displayed on the left side of zero key button.
final PinpadExtraKey? leftExtraKey;