rightExtraKey property
Data for widget that will be displayed on the right side of zero key button.
Implementation
final PinpadExtraKey? rightExtraKey;
Data for widget that will be displayed on the right side of zero key button.
final PinpadExtraKey? rightExtraKey;