builder property

Widget Function(bool isPressed, bool isPointed) builder
final

Widget that will be displayed as an extra key with all. It will be decorated according to the provided set of properties for pinpad.

Implementation

final Widget Function(bool isPressed, bool isPointed) builder;