PinpadKey class
Custom pinpad key widget.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- PinpadKey
Constructors
- PinpadKey({required Widget builder(bool isPressed, bool isPointed), VoidCallback? onTap, VoidCallback? onTapStart, VoidCallback? onTapEnd, BoxDecoration? defaultDecoration, BoxDecoration? pressedDecoration, BoxDecoration? disabledDecoration, double? width, double? height, bool enabled = true, Key? key})
-
Custom pinpad key widget.
const
Properties
- builder → Widget Function(bool isPressed, bool isPointed)
-
Child widget to be displayed as pinpad key
final
- defaultDecoration → BoxDecoration?
-
Decoration that will be applied when the key is not pressed
finalinherited
- disabledDecoration → BoxDecoration?
-
Decoration that will be applied when the key is disabled
finalinherited
- enabled → bool
-
If key is enabled
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
Height of the key
finalinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onTap → VoidCallback?
-
onTap callback
finalinherited
- onTapEnd → VoidCallback?
-
Callback that is called when the key is released.
finalinherited
- onTapStart → VoidCallback?
-
Callback that is called when the is pressed.
finalinherited
- pressedDecoration → BoxDecoration?
-
Decoration that will be applied when the key is pressed
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → double?
-
Width of the key
finalinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< StatefulWidget> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited