pin_ui library
Classes
- PinIndicator
- Pin indicator widget.
- PinIndicatorAnimationController
- Controller for managing animations for PinIndicator.
- PinIndicatorItem
- Simple in indicator item that can be customized with decoration and size.
- Pinpad
- Pinpad widget. Pinpad is a special keyboard for entering pin code.
- PinpadExtraKey
- Class representing data for extra pinpad key widget.
- PinpadKey
- Custom pinpad key widget.
- PinpadTextKey
- Text pinpad key widget with text.
Enums
- PinClearAnimation
- Enum with all clear animations that can be played via controller in Pin indicator.
- PinEraseAnimation
- Enum with all erase animations that can be played via controller in Pin indicator.
- PinErrorAnimation
- Enum with all error animations that can be played via controller in Pin indicator.
- PinIdleAnimation
- Enum with all idle animations that can be played via controller in Pin indicator.
- PinInputAnimation
- Enum with all input animations that can be played via controller in Pin indicator.
- PinLoadingAnimation
- Enum with all loading animations that can be played via controller in Pin indicator.
- PinSuccessAnimation
- Enum with all success animations that can be played via controller in Pin indicator.
Typedefs
- PinIndicatorItemBuilder = PreferredSizeWidget Function(int index)
- Pin indicator item widget builder.
Exceptions / Errors
- PinIndicatorAnimationControllerNotInitializedException
- Exceptions thrown by PinIndicatorController when vibration is not initialized yet, but animation with vibration is called.