PinIndicator class
Pin indicator widget.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- PinIndicator
Constructors
- PinIndicator({required int length, required int currentLength, required bool isError, required bool isSuccess, PinIndicatorAnimationController? controller, BoxDecoration? errorDecoration, BoxDecoration? successDecoration, BoxDecoration? inputDecoration, BoxDecoration? defaultDecoration, double spacing = 24.0, double itemSize = 14.0, Widget? loadingCollapseAnimationChild, Widget? successCollapseAnimationChild, Key? key})
- Simple decorated Pin Indicator widget.
- PinIndicator.builder({required int length, required int currentLength, required bool isError, required bool isSuccess, required PinIndicatorItemBuilder errorItemBuilder, required PinIndicatorItemBuilder successItemBuilder, required PinIndicatorItemBuilder inputItemBuilder, required PinIndicatorItemBuilder defaultItemBuilder, PinIndicatorAnimationController? controller, double spacing = 24.0, Widget? loadingCollapseAnimationChild, Widget? successCollapseAnimationChild, Key? key})
-
Pin Indicator builder version where you can build any child via builders
as items.
const
Properties
- controller → PinIndicatorAnimationController?
-
Controller for managing animations.
final
- currentLength → int
-
Current number of entered pin code symbols.
final
- defaultItemBuilder → PinIndicatorItemBuilder
-
Builder for item in default state.
final
- errorItemBuilder → PinIndicatorItemBuilder
-
Builder for item in error state.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputItemBuilder → PinIndicatorItemBuilder
-
Builder for item in input state (for entered symbols).
final
- isError → bool
-
If Pin indicator is in error state (wrong pin entered).
final
- isSuccess → bool
-
If Pin indicator is in success state (correct pin entered).
final
- itemSize → double
-
Size of Pin indicator item. Value is used in some animations.
If size is not symmetric or different, provide estimate value.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- length → int
-
Number of items in Pin indicator.
final
- loadingCollapseAnimationChild → Widget?
-
Widget that will appear on the screen after all indicator items are
collapsed in case of PinLoadingAnimation.collapse is chosen.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spacing → double
-
Spacing between Pin indicator items.
final
- successCollapseAnimationChild → Widget?
-
Widget that will appear on the screen after all indicator items are
collapsed in case of PinSuccessAnimation.collapse is chosen.
final
- successItemBuilder → PinIndicatorItemBuilder
-
Builder for item in success state.
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< PinIndicator> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited