loadingCollapseAnimationChild property
Widget that will appear on the screen after all indicator items are collapsed in case of PinLoadingAnimation.collapse is chosen.
Implementation
final Widget? loadingCollapseAnimationChild;
Widget that will appear on the screen after all indicator items are collapsed in case of PinLoadingAnimation.collapse is chosen.
final Widget? loadingCollapseAnimationChild;