Pinpad class
Pinpad widget. Pinpad is a special keyboard for entering pin code.
- Inheritance
Constructors
- Pinpad({required dynamic onKeyTap(String key), BoxDecoration? keyDefaultDecoration, BoxDecoration? keyPressedDecoration, BoxDecoration? keyDisabledDecoration, double? horizontalSpacing, double? verticalSpacing, bool enabled = true, PinpadExtraKey? rightExtraKey, PinpadExtraKey? leftExtraKey, TextStyle? keyDefaultTextStyle, TextStyle? keyPressedTextStyle, TextStyle? keyDisabledTextStyle, double? keyHeight, double? keyWidth, bool vibrationEnabled = false, bool isVisible = true, Key? key})
-
Pinpad widget. Pinpad is a special keyboard for entering pin code.
const
Properties
- enabled → bool
-
If pinpad is enabled. If disabled it can not be touched and allies
disabled decoration if provided.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- horizontalSpacing → double?
-
Horizontal spacing between keys.
final
- isVisible → bool
-
If pinpad is visible. When it is hidden, size will remain the same.
This parameter is useful for some Pin Indicator animations.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- keyDefaultDecoration → BoxDecoration?
-
Default decoration that will be applied for every key.
final
- keyDefaultTextStyle → TextStyle?
-
Default text style for 0-9 keys
final
- keyDisabledDecoration → BoxDecoration?
-
Decoration that will be applied for keys when they are disabled.
final
- keyDisabledTextStyle → TextStyle?
-
Text style for 0-9 keys when they are disabled
final
- keyHeight → double?
-
Key height
final
- keyPressedDecoration → BoxDecoration?
-
Decoration that will be applied for key when it is pressed.
final
- keyPressedTextStyle → TextStyle?
-
Text style for 0-9 keys when they are pressed
final
- keyWidth → double?
-
Key width
final
- leftExtraKey → PinpadExtraKey?
-
Data for widget that will be displayed on the left side of zero key button.
final
- onKeyTap → dynamic Function(String key)
-
Callback for handling pinpad key tap. It returns tapped key value.
final
- rightExtraKey → PinpadExtraKey?
-
Data for widget that will be displayed on the right side of zero key button.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- verticalSpacing → double?
-
Vertical spacing between keys.
final
- vibrationEnabled → bool
-
If on tap feedback vibration is enabled.
You better set this parameter to false if you have enabled input and erase
animations vibration when animating.
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< Pinpad> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited