PinpadExtraKey class
Class representing data for extra pinpad key widget.
Constructors
- PinpadExtraKey({required Widget builder(bool isPressed, bool isPointed), required void onTap()})
- Class representing data for extra pinpad key widget.
Properties
- builder → Widget Function(bool isPressed, bool isPointed)
-
Widget that will be displayed as an extra key with all.
It will be decorated according to the provided set of properties for pinpad.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- onTap → void Function()
-
Callback for extra key that will be called when it is tapped.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited